"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseConfig = exports.readConfig = exports.possibleFilenames = void 0;
const tslib_1 = require("tslib");
const node_path_1 = (0, tslib_1.__importDefault)(require("node:path"));
const log_1 = require("../util/log");
const defaults_1 = require("./defaults");
exports.possibleFilenames = [
    'declarator.js',
    'declarator.json',
    '.declarator.js',
    '.declarator.json',
    '.declaratorrc',
    '.declaratorrc.js',
    '.declaratorrc.json'
];
function readConfig(directory = process.cwd()) {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        for (const possibleFile of exports.possibleFilenames) {
            const name = node_path_1.default.join(directory, possibleFile);
            try {
                return Promise.resolve().then(() => (0, tslib_1.__importStar)(require(name)));
            }
            catch (_a) {
                log_1.log.debug `${name} could not be found.`;
                continue;
            }
        }
        const packagePath = node_path_1.default.join(directory, 'package.json');
        try {
            const packageJson = (yield Promise.resolve().then(() => (0, tslib_1.__importStar)(require(packagePath))));
            const declarator = packageJson['declarator'];
            if (!declarator) {
                log_1.log.debug `${packagePath} does not contain a declarator section.`;
                throw null;
            }
            return declarator;
        }
        catch (err) {
            log_1.log.info `No config file could be found. Tried (${exports.possibleFilenames})`;
            return defaults_1.DEFAULT_OPTIONS;
        }
    });
}
exports.readConfig = readConfig;
function parseConfig(config) {
    const read = typeof config === 'function' ? config() : config;
    return Object.assign(Object.assign({}, defaults_1.DEFAULT_OPTIONS), read);
}
exports.parseConfig = parseConfig;
