"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const tslib_1 = require("tslib");
const config_1 = require("../config");
const package_1 = require("../package");
const log_1 = require("../util/log");
function run() {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        const config = yield (0, config_1.readConfig)();
        const { defaults, packages } = (0, config_1.parseConfig)(config);
        if (packages.length < 1) {
            log_1.log.warn `No packages could be found for this configuration.`;
            return;
        }
        const promises = packages.map((pkg) => {
            if (Array.isArray(pkg)) {
                const [name, config] = pkg;
                return (0, package_1.processPackage)(name, config.merge ? Object.assign(Object.assign({}, defaults), config) : config);
            }
            return (0, package_1.processPackage)(pkg, defaults);
        });
        const results = yield Promise.all(promises);
        log_1.log.info `Generated types for ${results.filter((r) => !!r).length} package(s) out of ${packages.length}.`;
    });
}
exports.run = run;
