"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.emitTypes = void 0;
const tslib_1 = require("tslib");
const promises_1 = (0, tslib_1.__importDefault)(require("node:fs/promises"));
const node_path_1 = (0, tslib_1.__importDefault)(require("node:path"));
const log_1 = require("../util/log");
const shell_1 = require("../util/shell");
const info_1 = require("./info");
function emitTypes(name, cwd, info) {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        const infoPath = node_path_1.default.join(cwd, info_1.filename);
        const [stdout, error] = yield (0, shell_1.childExec)(`tsc -p ${infoPath}`, { cwd });
        info.declarator.typed = !!error;
        if (error) {
            log_1.log.error `Could not complete type generation for ${name}. Check debug logs`;
            log_1.log.debug `${error.err}`;
            log_1.log.debug `${stdout}`;
            log_1.log.debug `${error.stderr}`;
        }
        else {
            log_1.log.debug `${name} was typed`;
            log_1.log.debug `${stdout}`;
        }
        yield promises_1.default.writeFile(infoPath, JSON.stringify(info));
        return info.declarator.typed;
    });
}
exports.emitTypes = emitTypes;
