"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.processPackage = void 0;
const tslib_1 = require("tslib");
const path_1 = (0, tslib_1.__importDefault)(require("path"));
const defaults_1 = require("../config/defaults");
const api_1 = require("../npm/api");
const log_1 = require("../util/log");
const package_json_1 = require("../util/package-json");
const path_2 = require("../util/path");
const emitter_1 = require("./emitter");
const info_1 = require("./info");
function processPackage(name, config) {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        const pkgDir = (0, path_2.findPackage)(name);
        const packageInfo = yield (0, info_1.getPackageInfo)(name, pkgDir, config);
        if (packageInfo.declarator.typed) {
            log_1.log.debug `Package ${name} is already typed`;
            return false;
        }
        if (!config.ignoreDtCheck) {
            const existsTypes = yield (0, api_1.hasNpmPackage)(`@types/${name}`);
            if (existsTypes) {
                log_1.log.warn `An @types/${name} package is available!\n Install it at https://npmjs.com/package/@types/${name}. Use ignoreDtCheck to hide this warning.`;
                return false;
            }
        }
        const emitted = yield (0, emitter_1.emitTypes)(name, pkgDir, packageInfo);
        if (emitted) {
            yield (0, package_json_1.editPackageJson)(pkgDir, (atual) => {
                var _a, _b, _c;
                const main = ((_a = atual.main) === null || _a === void 0 ? void 0 : _a.replace(/js$/, 'd.ts')) || 'index.d.ts';
                const outDir = (_c = (_b = packageInfo.compilerOptions) === null || _b === void 0 ? void 0 : _b.outDir) !== null && _c !== void 0 ? _c : defaults_1.DEFAULT_OPTIONS.defaults.compilerOptions.outDir;
                return Object.assign(Object.assign({}, atual), { types: path_1.default.join(outDir, main) });
            });
        }
        return emitted;
    });
}
exports.processPackage = processPackage;
