"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPackageInfo = exports.infoVersion = exports.filename = void 0;
const tslib_1 = require("tslib");
const promises_1 = (0, tslib_1.__importDefault)(require("node:fs/promises"));
const node_path_1 = (0, tslib_1.__importDefault)(require("node:path"));
const log_1 = require("../util/log");
exports.filename = 'declarator.generated.json';
exports.infoVersion = 1;
function getPackageInfo(name, packagePath, config) {
    return (0, tslib_1.__awaiter)(this, void 0, void 0, function* () {
        const infoPath = node_path_1.default.join(packagePath, exports.filename);
        let info;
        try {
            const json = (yield promises_1.default.readFile(infoPath)).toString();
            const content = JSON.parse(json);
            const { declarator } = content;
            const outdated = (declarator === null || declarator === void 0 ? void 0 : declarator.version) < exports.infoVersion;
            const newer = (declarator === null || declarator === void 0 ? void 0 : declarator.version) > exports.infoVersion;
            if (outdated || newer) {
                log_1.log.warn `package ${name} has ${outdated ? 'an outdated' : 'a newer'} declarator version of ${declarator === null || declarator === void 0 ? void 0 : declarator.version}`;
                yield promises_1.default.writeFile(node_path_1.default.join(packagePath, exports.filename + '.old'), JSON.stringify(content, null, 2));
                log_1.log.info `A ${infoPath}.old was generated.`;
                throw null;
            }
            info = content;
        }
        catch (_a) {
            info = Object.assign({ declarator: { typed: false, version: exports.infoVersion, name } }, config);
            yield promises_1.default.writeFile(infoPath, JSON.stringify(info));
            log_1.log.debug `Wrote a default config for ${name}.`;
        }
        return info;
    });
}
exports.getPackageInfo = getPackageInfo;
