"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.log = void 0;
const ResetColor = '\x1b[0m';
const Levels = {
    warn: '\x1b[33m',
    debug: '\x1b[36m',
    error: '\x1b[31m',
    info: '\x1b[32m'
};
const describeValue = (value) => {
    if (Array.isArray(value))
        return value.map((value) => describeValue(value)).join(', ');
    if (value instanceof Error)
        return `${value.message}\n${value.stack || 'No stack trace available'}`;
    if (typeof value === 'object')
        return JSON.stringify(value, null, 2);
    return String(value);
};
const templateLog = (level) => {
    return ({ raw }, ...values) => {
        const msg = raw.reduce((acc, str, i) => {
            const value = values[i];
            return (acc + str + (value !== null && value !== undefined ? describeValue(value) : ''));
        }, '');
        console.log(`${Levels[level]}[declarator]${ResetColor}: ${msg}`);
    };
};
exports.log = {
    info: templateLog('info'),
    warn: templateLog('warn'),
    debug: templateLog('debug'),
    error: templateLog('error')
};
